@@ -1,29 +1,29 @@
 /* APSearch.m
  * Controls the chart generation
  *
- * Copyright (C) 2004-2014 by Cenon GmbH
+ * Copyright (C) 2004 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * Created:  2004-05-20
- * Modified: 2009-02-22
+ * Modified: 2004-05-20
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the Cenon Public License as
- * published by Cenon GmbH. Among other things, the
+ * modify it under the terms of the vhf Public License as
+ * published by vhf interservice GmbH. Among other things, the
  * License requires that the copyright notices and this notice
  * be preserved on all copies.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * See the Cenon Public License for more details.
+ * See the vhf Public License for more details.
  *
- * You should have received a copy of the Cenon Public License along
- * with this program; see the file LICENSE. If not, write to Cenon.
+ * You should have received a copy of the vhf Public License along
+ * with this program; see the file LICENSE. If not, write to vhf.
  *
- * Cenon GmbH, Schwabstr. 45, 72108 Rottenburg a.N., Germany
- * eMail: info@cenon.de
- * http://www.cenon.info
+ * vhf interservice GmbH, Im Marxle 3, 72119 Altingen, Germany
+ * eMail: info@vhf.de
+ * http://www.vhf.de
  */
 
 #include <VHFShared/vhfCommonFunctions.h>
@@ -37,7 +37,6 @@
 #include "../astroMessages.h"
 #include "../astroCommon.h"
 #include "../AstroPrincipal.h"
-#include "../AstroDate.h"			// date formats
 #include "../Astro.bproj/AstroController.h"	// Preferences
 
 @interface APSearch(PrivateMethods)
@@ -72,8 +71,7 @@
 {   NSString	*string = [fromField stringValue];
 
     /* wrong date format -> update */
-    if ( [string length] < 3 || [[toField stringValue] length] < 3 ||
-         [string characterAtIndex:2] != [Prefs_DateFormat characterAtIndex:2] )
+    if ( [string characterAtIndex:2] != [Prefs_DateFormat characterAtIndex:2] )
     {
         [fromField setStringValue:[[NSCalendarDate date] descriptionWithCalendarFormat:Prefs_DateFormat]];
         [toField   setStringValue:[[NSCalendarDate date] descriptionWithCalendarFormat:Prefs_DateFormat]];
@@ -112,12 +110,11 @@
 }
 
 - (NSCalendarDate*)dateWithString:(NSString*)string
-{   NSString		*dateFormat = astroDateFormatForString(string);
-    NSCalendarDate	*date = [NSCalendarDate dateWithString:string calendarFormat:dateFormat];
+{   NSString		*errorDate = ([Prefs_DateFormat isEqual:@"%d.%m.%Y"]) ? DATE1_STRING : DATE2_STRING;
+    NSCalendarDate	*date = [NSCalendarDate dateWithString:string calendarFormat:Prefs_DateFormat];
 
-    [date setTimeZone:[NSTimeZone timeZoneForSecondsFromGMT:0]];    // FIXME: this may cut hours, better is [APChart date]
     if (!date)
-        NSRunAlertPanel(@"", WRONGDATEFORMAT_STRING, OK_STRING, nil, nil, astroErrorDate());
+        NSRunAlertPanel(@"", WRONGDATEFORMAT_STRING, OK_STRING, nil, nil, errorDate);
     return date;
 }
 
@@ -135,54 +132,35 @@
 {   NSCalendarDate	*dateFrom = [self dateWithString:[fromField stringValue]];
     NSCalendarDate	*dateTo   = [self dateWithString:[toField   stringValue]];
     NSDictionary	*searchDict = nil;
-    NSArray         *dividers = [self dividers];
-    NSString		*planet[2], *aspectStr;
-    BOOL            searchAngles  = [(NSButton*)[aspectSwitches cellAtRow:SHOW_ASPECTS column:0] state];
-    BOOL            searchMirrors = [(NSButton*)[aspectSwitches cellAtRow:SHOW_MIRRORS column:0] state];
-    int             i;
+    NSArray		*dividers = [self dividers];
+    NSString		*planet1 = [planetList objectAtIndex:[planet1Popup indexOfSelectedItem]];
+    NSString		*planet2 = [planetList objectAtIndex:[planet2Popup indexOfSelectedItem]];
+    BOOL		searchAngles  = [[aspectSwitches cellAtRow:SHOW_ASPECTS column:0] state];
+    BOOL		searchMirrors = [[aspectSwitches cellAtRow:SHOW_MIRRORS column:0] state];
+    int			i;
     NSString		*dateFormat = [NSString stringWithFormat:@"%@ %%H:%%M", Prefs_DateFormat];
     NSMutableString	*mString = [NSMutableString string];
-    BOOL            displaySymbols = YES, displayAngles = NO;
+    BOOL		displaySymbols = YES, displayAngles = NO;
+    NSString		*aspectStr;
     NSMutableAttributedString	*attrString = [[NSMutableAttributedString new] autorelease];
-    NSMutableAttributedString	*aString    = [[NSMutableAttributedString new] autorelease];
+    NSMutableAttributedString	*aString = [[NSMutableAttributedString new] autorelease];
     NSFont			*systemFont = [NSFont systemFontOfSize:12.0];
     NSFont			*symbolFont = [NSFont fontWithName:Prefs_AstroFont size:12.0];
 
     if (!dateFrom || !dateTo)
         return;
 
-    planet[0] = [planetList objectAtIndex:[planet1Popup indexOfSelectedItem]];
-    planet[1] = [planetList objectAtIndex:[planet2Popup indexOfSelectedItem]];
-
     if (!symbolFont)
-        symbolFont = [NSFont fontWithName:@"CenonAstro" size:12.0];
-    if (!symbolFont)
-        symbolFont = [NSFont fontWithName:@"vhfAstro"   size:12.0];
+        [NSFont fontWithName:@"vhfAstro" size:12.0];
     if (!aspectList)
         aspectList = [NSMutableDictionary new];
 
     if ([searchTypePopup indexOfSelectedItem] == SEARCH_ASPECTS)
-    {   AstroPanel	*astroPanel = [Astro_Principal astroPanel];
-        APChart		*astroChart = (APChart*)[astroPanel windowAt:AP_CHART];
-
-        /* if planet1 or planet2 == Node or Apogee, we have to check, if true or mean */
-        for (i=0; i<2; i++)
-            if ( ! [Prefs_Objects containsObject:planet[i]] )
-            {
-                if ([planet[i] isEqual:@"True Node"])
-                    planet[i] = @"Node";	// Mean Node
-                else if ([planet[i] isEqual:@"True Apogee"])
-                    planet[i] = @"Apogee";	// Mean Apogee
-            }
-        [ephemerisSearch setTopocentricSearch:Prefs_Topocentric
-                                          lat:[astroChart latitude] lon:[astroChart longitude] elev:0];
-        [ephemerisSearch setHeliocentricSearch:Prefs_Heliocentric];
-        searchDict = [ephemerisSearch searchAspect:planet[0] :planet[1]
+        searchDict = [ephemerisSearch searchAspect:planet1 :planet2
                                           dividers:dividers
                                       searchAngles:searchAngles searchMirrors:searchMirrors
                                           fromDate:dateFrom toDate:dateTo
-                                    searchInterval:30];
-    }
+                                    searchInterval:60];
     else	// search for transits
         ; // FIXME
 
@@ -260,13 +238,13 @@
 /* calculate chart for selected aspect
  */
 - (void)textViewDidChangeSelection:(NSNotification *)aNotification
-{   int                 loc = [textView selectedRange].location;
-    NSString            *string = [textView string];
-    int                 line = [string countOfCharacter:'\n' inRange:NSMakeRange(0, loc)];
-    NSCalendarDate      *date;
-    APChart             *apChart = [[Astro_Principal astroPanel] windowAt:AP_CHART];
-    NSMutableDictionary *dict;
-    NSDictionary        *composite;
+{   int			loc = [textView selectedRange].location;
+    NSString		*string = [textView string];
+    int			line = [string countOfCharacter:'\n' inRange:NSMakeRange(0, loc)];
+    NSCalendarDate	*date;
+    APChart		*apChart = [[Astro_Principal astroPanel] windowAt:AP_CHART];
+    NSMutableDictionary	*dict;
+    NSDictionary	*composite;
 
     if (![aspectKeys count])
         return;
